@@ -1,7 +1,10 @@
 package DateTime::TimeZone::Local::Android;
-$DateTime::TimeZone::Local::Android::VERSION = '1.87';
+
 use strict;
 use warnings;
+use namespace::autoclean;
+
+our $VERSION = '2.05';
 
 use Try::Tiny;
 
@@ -19,9 +22,11 @@ sub EnvVars { return 'TZ' }
 
 # https://chromium.googlesource.com/native_client/nacl-bionic/+/upstream/master/libc/tzcode/localtime.c
 sub FromGetProp {
+    ## no critic (InputOutput::ProhibitBacktickOperators)
     my $name = `getprop persist.sys.timezone`;
     chomp $name;
     my $tz = try {
+        ## no critic (Variables::RequireInitializationForLocalVars)
         local $SIG{__DIE__};
         DateTime::TimeZone->new( name => $name );
     };
@@ -31,12 +36,11 @@ sub FromGetProp {
 
 # See the link above. Android always defaults to UTC
 sub FromDefault {
-    my $tz = try {
+    return try {
+        ## no critic (Variables::RequireInitializationForLocalVars)
         local $SIG{__DIE__};
-        $tz = DateTime::TimeZone->new( name => 'UTC' );
-    }
-
-    return $tz if $tz;
+        DateTime::TimeZone->new( name => 'UTC' );
+    };
 }
 
 1;
