@@ -1,7 +1,10 @@
 package DateTime::TimeZone::Local::Unix;
-$DateTime::TimeZone::Local::Unix::VERSION = '1.87';
+
 use strict;
 use warnings;
+use namespace::autoclean;
+
+our $VERSION = '2.05';
 
 use Cwd 3;
 use Try::Tiny;
@@ -21,7 +24,9 @@ sub Methods {
 
 sub EnvVars { return 'TZ' }
 
+## no critic (Variables::ProhibitPackageVars)
 our $EtcDir = '/etc';
+## use critic
 
 sub _EtcFile {
     shift;
@@ -44,10 +49,10 @@ sub FromEtcLocaltime {
     $real_name ||= $class->_FindMatchingZoneinfoFile($lt_file);
 
     if ( defined $real_name ) {
-        my ( $vol, $dirs, $file ) = File::Spec->splitpath($real_name);
+        my ( undef, $dirs, $file ) = File::Spec->splitpath($real_name);
 
-        my @parts
-            = grep { defined && length } File::Spec->splitdir($dirs), $file;
+        my @parts = grep { defined && length } File::Spec->splitdir($dirs),
+            $file;
 
         foreach my $x ( reverse 0 .. $#parts ) {
             my $name = (
@@ -57,6 +62,7 @@ sub FromEtcLocaltime {
             );
 
             my $tz = try {
+                ## no critic (Variables::RequireInitializationForLocalVars)
                 local $SIG{__DIE__};
                 DateTime::TimeZone->new( name => $name );
             };
@@ -74,10 +80,13 @@ sub _Readlink {
     return Cwd::abs_path($link);
 }
 
+## no critic (Variables::ProhibitPackageVars)
 our $ZoneinfoDir = '/usr/share/zoneinfo';
+## use critic
+
 # for systems where /etc/localtime is a copy of a zoneinfo file
 sub _FindMatchingZoneinfoFile {
-    my $class         = shift;
+    shift;
     my $file_to_match = shift;
 
     return unless -d $ZoneinfoDir;
@@ -90,6 +99,7 @@ sub _FindMatchingZoneinfoFile {
 
     my $real_name;
     try {
+        ## no critic (Variables::RequireInitializationForLocalVars)
         local $SIG{__DIE__};
         local $_;
 
@@ -135,14 +145,15 @@ sub FromEtcTimezone {
 
     open my $fh, '<', $tz_file
         or die "Cannot read $tz_file: $!";
-    my $name = join '', <$fh>;
-    close $fh;
+    my $name = do { local $/ = undef; <$fh> };
+    close $fh or die $!;
 
     $name =~ s/^\s+|\s+$//g;
 
     return unless $class->_IsValidName($name);
 
     return try {
+        ## no critic (Variables::RequireInitializationForLocalVars)
         local $SIG{__DIE__};
         DateTime::TimeZone->new( name => $name );
     };
@@ -154,6 +165,7 @@ sub FromEtcTIMEZONE {
     my $tz_file = $class->_EtcFile('TIMEZONE');
     return unless -f $tz_file && -r _;
 
+    ## no critic (InputOutput::RequireBriefOpen)
     open my $fh, '<', $tz_file
         or die "Cannot read $tz_file: $!";
 
@@ -165,11 +177,12 @@ sub FromEtcTIMEZONE {
         }
     }
 
-    close $fh;
+    close $fh or die $!;
 
     return unless $class->_IsValidName($name);
 
     return try {
+        ## no critic (Variables::RequireInitializationForLocalVars)
         local $SIG{__DIE__};
         DateTime::TimeZone->new( name => $name );
     };
@@ -187,6 +200,7 @@ sub FromEtcSysconfigClock {
     return unless $class->_IsValidName($name);
 
     return try {
+        ## no critic (Variables::RequireInitializationForLocalVars)
         local $SIG{__DIE__};
         DateTime::TimeZone->new( name => $name );
     };
@@ -194,16 +208,19 @@ sub FromEtcSysconfigClock {
 
 # this is a separate function so that it can be overridden in the test suite
 sub _ReadEtcSysconfigClock {
-    my $class      = shift;
+    shift;
     my $clock_file = shift;
 
     open my $fh, '<', $clock_file
         or die "Cannot read $clock_file: $!";
 
+    ## no critic (Variables::RequireInitializationForLocalVars)
     local $_;
     while (<$fh>) {
         return $1 if /^(?:TIME)?ZONE="([^"]+)"/;
     }
+
+    close $fh or die $!;
 }
 
 sub FromEtcDefaultInit {
@@ -217,6 +234,7 @@ sub FromEtcDefaultInit {
     return unless $class->_IsValidName($name);
 
     return try {
+        ## no critic (Variables::RequireInitializationForLocalVars)
         local $SIG{__DIE__};
         DateTime::TimeZone->new( name => $name );
     };
@@ -225,16 +243,19 @@ sub FromEtcDefaultInit {
 # this is a separate function so that it can be overridden in the test
 # suite
 sub _ReadEtcDefaultInit {
-    my $class     = shift;
+    shift;
     my $init_file = shift;
 
     open my $fh, '<', $init_file
         or die "Cannot read $init_file: $!";
 
+    ## no critic (Variables::RequireInitializationForLocalVars)
     local $_;
     while (<$fh>) {
         return $1 if /^TZ=(.+)/;
     }
+
+    close $fh or die $!;
 }
 
 1;
@@ -245,13 +266,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 DateTime::TimeZone::Local::Unix - Determine the local system's time zone on Unix
 
 =head1 VERSION
 
-version 1.87
+version 2.05
 
 =head1 SYNOPSIS
 
@@ -311,13 +334,20 @@ If this file exists, it is opened and we look for a line starting like
 
 =back
 
+=head1 SUPPORT
+
+Bugs may be submitted through L<the RT bug tracker|http://rt.cpan.org/Public/Dist/Display.html?Name=DateTime-TimeZone>
+(or L<bug-datetime-timezone@rt.cpan.org|mailto:bug-datetime-timezone@rt.cpan.org>).
+
+I am also usually active on IRC as 'drolsky' on C<irc://irc.perl.org>.
+
 =head1 AUTHOR
 
 Dave Rolsky <autarch@urth.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by Dave Rolsky.
+This software is copyright (c) 2016 by Dave Rolsky.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
