@@ -1,33 +1,45 @@
 package DateTime::TimeZone::OffsetOnly;
-$DateTime::TimeZone::OffsetOnly::VERSION = '1.95';
+
 use strict;
 use warnings;
+use namespace::autoclean;
+
+our $VERSION = '2.05';
 
 use parent 'DateTime::TimeZone';
 
 use DateTime::TimeZone::UTC;
-use Params::Validate qw( validate SCALAR );
+use Params::ValidationCompiler 0.13 qw( validation_for );
+use Specio::Library::String;
 
-sub new {
-    my $class = shift;
-    my %p     = validate(
-        @_, {
-            offset => { type => SCALAR },
-        }
+{
+    my $validator = validation_for(
+        name             => '_check_new_params',
+        name_is_optional => 1,
+        params           => {
+            offset => {
+                type => t('NonEmptyStr'),
+            },
+        },
     );
 
-    my $offset = DateTime::TimeZone::offset_as_seconds( $p{offset} );
+    sub new {
+        my $class = shift;
+        my %p     = $validator->(@_);
 
-    die "Invalid offset: $p{offset}\n" unless defined $offset;
+        my $offset = DateTime::TimeZone::offset_as_seconds( $p{offset} );
 
-    return DateTime::TimeZone::UTC->new unless $offset;
+        die "Invalid offset: $p{offset}\n" unless defined $offset;
 
-    my $self = {
-        name   => DateTime::TimeZone::offset_as_string($offset),
-        offset => $offset,
-    };
+        return DateTime::TimeZone::UTC->new unless $offset;
 
-    return bless $self, $class;
+        my $self = {
+            name   => DateTime::TimeZone::offset_as_string($offset),
+            offset => $offset,
+        };
+
+        return bless $self, $class;
+    }
 }
 
 sub is_dst_for_datetime {0}
@@ -48,8 +60,8 @@ sub STORABLE_freeze {
 }
 
 sub STORABLE_thaw {
-    my $self       = shift;
-    my $cloning    = shift;
+    my $self = shift;
+    shift;
     my $serialized = shift;
 
     my $class = ref $self || $self;
@@ -75,13 +87,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 DateTime::TimeZone::OffsetOnly - A DateTime::TimeZone object that just contains an offset
 
 =head1 VERSION
 
-version 1.95
+version 2.05
 
 =head1 SYNOPSIS
 
@@ -116,6 +130,13 @@ is always used.
 
 Both of these methods return the offset in string form.
 
+=head1 SUPPORT
+
+Bugs may be submitted through L<the RT bug tracker|http://rt.cpan.org/Public/Dist/Display.html?Name=DateTime-TimeZone>
+(or L<bug-datetime-timezone@rt.cpan.org|mailto:bug-datetime-timezone@rt.cpan.org>).
+
+I am also usually active on IRC as 'drolsky' on C<irc://irc.perl.org>.
+
 =head1 AUTHOR
 
 Dave Rolsky <autarch@urth.org>
